==> jc-1.4.0.tar.gz: gnu/java/net/CRLFOutputStream.h <==
// public class gnu.java.net.CRLFOutputStream

// class file dependencies
// @dep_class c4a1846eb7542c90 gnu_java_net_CRLFOutputStream
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterOutputStream

#include "java/io/FilterOutputStream.h"

#ifndef _JC_gnu_java_net_CRLFOutputStream_H_
#define _JC_gnu_java_net_CRLFOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_net_CRLFOutputStream$sub_refs	_jc_gnu_java_net_CRLFOutputStream$sub_refs;
typedef struct _jc_gnu_java_net_CRLFOutputStream$sub_nonrefs	_jc_gnu_java_net_CRLFOutputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_CRLFOutputStream$refs	_jc_gnu_java_net_CRLFOutputStream$refs;
typedef struct _jc_gnu_java_net_CRLFOutputStream$nonrefs	_jc_gnu_java_net_CRLFOutputStream$nonrefs;
typedef struct _jc_gnu_java_net_CRLFOutputStream$object	_jc_gnu_java_net_CRLFOutputStream$object;

typedef struct _jc_gnu_java_net_CRLFOutputStream$fields_struct	_jc_gnu_java_net_CRLFOutputStream$fields_struct;
typedef const struct _jc_gnu_java_net_CRLFOutputStream$vmethods	_jc_gnu_java_net_CRLFOutputStream$vmethods;
typedef const struct _jc_gnu_java_net_CRLFOutputStream$vtable	_jc_gnu_java_net_CRLFOutputStream$vtable;
typedef const struct _jc_gnu_java_net_CRLFOutputStream$vtype	_jc_gnu_java_net_CRLFOutputStream$vtype;

// Class fields structure
struct _jc_gnu_java_net_CRLFOutputStream$fields_struct {
	_jc_byte_array	*CRLF;
	struct _jc_java_lang_String$object	*US__5fASCII;
	jint	CR;
	jint	LF;
};
extern _jc_gnu_java_net_CRLFOutputStream$fields_struct _jc_gnu_java_net_CRLFOutputStream$class_fields;

// Constructors
extern void _jc_gnu_java_net_CRLFOutputStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_gnu_java_net_CRLFOutputStream$object *, struct _jc_java_io_OutputStream$object *);

// Virtual methods
extern void _jc_gnu_java_net_CRLFOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_gnu_java_net_CRLFOutputStream$object *, jint);
extern void _jc_gnu_java_net_CRLFOutputStream$method$write$741cedc3a0899944(_jc_env *, struct _jc_gnu_java_net_CRLFOutputStream$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_java_net_CRLFOutputStream$method$write$18e189e8fc25f121(_jc_env *, struct _jc_gnu_java_net_CRLFOutputStream$object *, struct _jc_byte_array *);
extern void _jc_gnu_java_net_CRLFOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_gnu_java_net_CRLFOutputStream$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_gnu_java_net_CRLFOutputStream$method$writeln$e773bcc130010bb6(_jc_env *, struct _jc_gnu_java_net_CRLFOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_CRLFOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_gnu_java_net_CRLFOutputStream$method_info$write$741cedc3a0899944;
extern _jc_method _jc_gnu_java_net_CRLFOutputStream$method_info$write$18e189e8fc25f121;
extern _jc_method _jc_gnu_java_net_CRLFOutputStream$method_info$write$306a698343ec27e8;
extern _jc_method _jc_gnu_java_net_CRLFOutputStream$method_info$writeln$e773bcc130010bb6;

// Static methods
extern void _jc_gnu_java_net_CRLFOutputStream$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_net_CRLFOutputStream$vmethods {
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_gnu_java_net_CRLFOutputStream$object *, jint);
	void	(*write$741cedc3a0899944)(_jc_env *, struct _jc_gnu_java_net_CRLFOutputStream$object *, struct _jc_java_lang_String$object *);
	void	(*write$18e189e8fc25f121)(_jc_env *, struct _jc_gnu_java_net_CRLFOutputStream$object *, struct _jc_byte_array *);
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_gnu_java_net_CRLFOutputStream$object *, struct _jc_byte_array *, jint, jint);
	void	(*writeln$e773bcc130010bb6)(_jc_env *, struct _jc_gnu_java_net_CRLFOutputStream$object *);
};

// Vtable
struct _jc_gnu_java_net_CRLFOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_gnu_java_net_CRLFOutputStream$vmethods	gnu_java_net_CRLFOutputStream;
};

// Vtype
struct _jc_gnu_java_net_CRLFOutputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_CRLFOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_CRLFOutputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_CRLFOutputStream$refs {
    _jc_gnu_java_net_CRLFOutputStream$sub_refs	gnu_java_net_CRLFOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_CRLFOutputStream$sub_nonrefs {
	jint	last;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_CRLFOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_gnu_java_net_CRLFOutputStream$sub_nonrefs	gnu_java_net_CRLFOutputStream;
};

// Object instance structure
struct _jc_gnu_java_net_CRLFOutputStream$object {
	_jc_gnu_java_net_CRLFOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_CRLFOutputStream$vtype	*vtype;
	_jc_gnu_java_net_CRLFOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_CRLFOutputStream$vtype _jc_gnu_java_net_CRLFOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_CRLFOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_CRLFOutputStream$class_object;

#endif	/* _JC_gnu_java_net_CRLFOutputStream_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/CRLFOutputStream.h <==
// public class gnu.java.net.CRLFOutputStream

// class file dependencies
// @dep_class c4a1846eb7542c90 gnu_java_net_CRLFOutputStream
// @dep_class fddb41323d9c4cee java_io_FilterOutputStream
// @dep_class 4026d3144d6654d8 java_io_OutputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_FilterOutputStream

#include "java/io/FilterOutputStream.h"

#ifndef _JC_gnu_java_net_CRLFOutputStream_H_
#define _JC_gnu_java_net_CRLFOutputStream_H_

// Forward structure declarations
struct _jc_java_io_OutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_net_CRLFOutputStream$sub_refs	_jc_gnu_java_net_CRLFOutputStream$sub_refs;
typedef struct _jc_gnu_java_net_CRLFOutputStream$sub_nonrefs	_jc_gnu_java_net_CRLFOutputStream$sub_nonrefs;
typedef struct _jc_gnu_java_net_CRLFOutputStream$refs	_jc_gnu_java_net_CRLFOutputStream$refs;
typedef struct _jc_gnu_java_net_CRLFOutputStream$nonrefs	_jc_gnu_java_net_CRLFOutputStream$nonrefs;
typedef struct _jc_gnu_java_net_CRLFOutputStream$object	_jc_gnu_java_net_CRLFOutputStream$object;

typedef struct _jc_gnu_java_net_CRLFOutputStream$fields_struct	_jc_gnu_java_net_CRLFOutputStream$fields_struct;
typedef const struct _jc_gnu_java_net_CRLFOutputStream$vmethods	_jc_gnu_java_net_CRLFOutputStream$vmethods;
typedef const struct _jc_gnu_java_net_CRLFOutputStream$vtable	_jc_gnu_java_net_CRLFOutputStream$vtable;
typedef const struct _jc_gnu_java_net_CRLFOutputStream$vtype	_jc_gnu_java_net_CRLFOutputStream$vtype;

// Class fields structure
struct _jc_gnu_java_net_CRLFOutputStream$fields_struct {
	_jc_byte_array	*CRLF;
	struct _jc_java_lang_String$object	*US__5fASCII;
	jint	CR;
	jint	LF;
};
extern _jc_gnu_java_net_CRLFOutputStream$fields_struct _jc_gnu_java_net_CRLFOutputStream$class_fields;

// Constructors
extern void _jc_gnu_java_net_CRLFOutputStream$method$_init$8b48f276bbc2c828(_jc_env *, struct _jc_gnu_java_net_CRLFOutputStream$object *, struct _jc_java_io_OutputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_net_CRLFOutputStream$method$write$6377ac6964854eb2(_jc_env *, struct _jc_gnu_java_net_CRLFOutputStream$object *, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_CRLFOutputStream$method$write$741cedc3a0899944(_jc_env *, struct _jc_gnu_java_net_CRLFOutputStream$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_CRLFOutputStream$method$write$18e189e8fc25f121(_jc_env *, struct _jc_gnu_java_net_CRLFOutputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_CRLFOutputStream$method$write$306a698343ec27e8(_jc_env *, struct _jc_gnu_java_net_CRLFOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_java_net_CRLFOutputStream$method$writeln$e773bcc130010bb6(_jc_env *, struct _jc_gnu_java_net_CRLFOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_CRLFOutputStream$method_info$write$6377ac6964854eb2;
extern _jc_method _jc_gnu_java_net_CRLFOutputStream$method_info$write$741cedc3a0899944;
extern _jc_method _jc_gnu_java_net_CRLFOutputStream$method_info$write$18e189e8fc25f121;
extern _jc_method _jc_gnu_java_net_CRLFOutputStream$method_info$write$306a698343ec27e8;
extern _jc_method _jc_gnu_java_net_CRLFOutputStream$method_info$writeln$e773bcc130010bb6;

// Static methods
extern void _jc_gnu_java_net_CRLFOutputStream$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_net_CRLFOutputStream$vmethods {
	void	(*write$6377ac6964854eb2)(_jc_env *, struct _jc_gnu_java_net_CRLFOutputStream$object *, jint) _JC_JCNI_ATTR;
	void	(*write$741cedc3a0899944)(_jc_env *, struct _jc_gnu_java_net_CRLFOutputStream$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*write$18e189e8fc25f121)(_jc_env *, struct _jc_gnu_java_net_CRLFOutputStream$object *, struct _jc_byte_array *) _JC_JCNI_ATTR;
	void	(*write$306a698343ec27e8)(_jc_env *, struct _jc_gnu_java_net_CRLFOutputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*writeln$e773bcc130010bb6)(_jc_env *, struct _jc_gnu_java_net_CRLFOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_CRLFOutputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_OutputStream$vmethods	java_io_OutputStream;
	_jc_java_io_FilterOutputStream$vmethods	java_io_FilterOutputStream;
	_jc_gnu_java_net_CRLFOutputStream$vmethods	gnu_java_net_CRLFOutputStream;
};

// Vtype
struct _jc_gnu_java_net_CRLFOutputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_net_CRLFOutputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_CRLFOutputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_CRLFOutputStream$refs {
    _jc_gnu_java_net_CRLFOutputStream$sub_refs	gnu_java_net_CRLFOutputStream;
    _jc_java_io_FilterOutputStream$sub_refs	java_io_FilterOutputStream;
    _jc_java_io_OutputStream$sub_refs	java_io_OutputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_CRLFOutputStream$sub_nonrefs {
	jint	last;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_CRLFOutputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_OutputStream$sub_nonrefs	java_io_OutputStream;
    _jc_java_io_FilterOutputStream$sub_nonrefs	java_io_FilterOutputStream;
    _jc_gnu_java_net_CRLFOutputStream$sub_nonrefs	gnu_java_net_CRLFOutputStream;
};

// Object instance structure
struct _jc_gnu_java_net_CRLFOutputStream$object {
	_jc_gnu_java_net_CRLFOutputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_CRLFOutputStream$vtype	*vtype;
	_jc_gnu_java_net_CRLFOutputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_CRLFOutputStream$vtype _jc_gnu_java_net_CRLFOutputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_CRLFOutputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_CRLFOutputStream$class_object;

#endif	/* _JC_gnu_java_net_CRLFOutputStream_H_ */
